# frozen_string_literal: false

##
# Add color to strings
class String
  ##
  # Colorizes every single character randomly in a string
  #
  # = Example
  #
  #   # Use on a String
  #   'Hello, world!'.color_randomize
  #
  # ---
  def color_randomize!
    chars.map! do |chr|
      "\e[#{rand(31..37)}m#{chr}\e[0m"
    end
  end

  ##
  # Colors a string in Green (2)
  #
  # = Example
  #
  #   # Use on a String
  #   'Hello, world!'.bright_white
  #
  #---
  def green
    "\e[32m#{self}\e[0m"
  end

  ##
  # Colors a string in Red (1)
  #
  # = Example
  #
  #   # Use on a String
  #   'Hello, world!'.bright_white
  #
  #---
  def red
    "\e[31m#{self}\e[0m"
  end

  ##
  # Colors a string in Bright White (15)
  #
  # = Example
  #
  #   # Use on a String
  #   'Hello, world!'.bright_white
  #
  #---
  def bright_white
    "\e[2;37m#{self}\e[0m"
  end

  ##
  # Makes a string bold
  #
  # = Example
  #
  #   # Use on a String
  #   'Hello, world!'.bold
  #
  #---
  def bold
    "\e[1m#{self}\e[22m"
  end

  ##
  # Makes a string blink
  #
  # = Example
  #
  #   # Use on a String
  #   'Hello, world!'.blink
  #
  #---
  def blink
    "\e[5m#{self}\e[25m"
  end
end

class Array
  ##
  # Make every single character in array bold
  #
  # = Example
  #
  #   # Use on array
  #   ['N', 'o', 't', 'h', 'i', 'n', 'g', '.'].bold!
  #
  # ---
  def bold!
    map! { |chr| "\e[1m#{chr}\e[22m" }
  end

  ##
  # Colorizes every single character randomly in array of strings
  #
  # = Example
  #
  #   # Use on Array
  #   ['Y', 'e', 's', '.'].color_randomize!
  #
  # ---
  def color_randomize!
    map! { |chr| "\e[#{rand(31..37)}m#{chr}\e[0m" }
  end

  ##
  # Makes every single character in array upcase
  # ! DOES NOT WORK PROPERLY YET !
  def upcase!
    map! { |chr| chr.upcase }
  end
end
