# frozen_string_literal: true

##
# Module to create an Instance of a MagicConchShell class
module Create
  ##
  # Constant to initialize a MagicConchShell with phrases
  ANSWERS_OF_LIFE = [
    'Maybe someday.',
    'Follow the seahorse.',
    'I don\'t think so.',
    'No.',
    'Yes.',
    'Try asking again.',
    'Nothing.',
    'Neither.'
  ].freeze

  ##
  # The main class to initialize a magic conch shell
  #
  # = Example
  #
  #   # Create Instance of MagicConchShell
  #   mcs = Create::MagicConchShell.new
  #
  #---
  class MagicConchShell
    ##
    # Initialize MagicConchShell with Create::ANSWERS_OF_LIFE
    def initialize
      @phrases = ANSWERS_OF_LIFE
    end

    ##
    # Let the magic conch shell speak out
    #
    # = Example
    #
    #   # Create Instance of MagicConchShell:
    #   mcs = Create::MagicConchShell.new
    #
    #   # Use the MagicConchShell without color:
    #   mcs.pull_the_cord
    #
    #   # Use the MagicConchShell with color randomize:
    #   mcs.pull_the_cord.color_randomize
    #
    #---
    def pull_the_cord
      @phrases[rand(@phrases.length - 1)].chars
    end
  end
end
